Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(5277)

Unified Diff: chrome/browser/chromeos/gdata/mock_drive_service.h

Issue 10828385: Rename DocumentsServiceInterface to DriveServiceInterface. (Closed) Base URL: svn://svn.chromium.org/chrome/trunk/src
Patch Set: Fix unnecessary includes. Created 8 years, 4 months ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
Index: chrome/browser/chromeos/gdata/mock_drive_service.h
diff --git a/chrome/browser/chromeos/gdata/mock_documents_service.h b/chrome/browser/chromeos/gdata/mock_drive_service.h
similarity index 93%
rename from chrome/browser/chromeos/gdata/mock_documents_service.h
rename to chrome/browser/chromeos/gdata/mock_drive_service.h
index c9ccf6e2b992b37d50845315169874a157c17974..10681e05d94857da83697e49e643b5911c0b95ce 100644
--- a/chrome/browser/chromeos/gdata/mock_documents_service.h
+++ b/chrome/browser/chromeos/gdata/mock_drive_service.h
@@ -2,29 +2,29 @@
// Use of this source code is governed by a BSD-style license that can be
// found in the LICENSE file.
// This file contains mocks for classes in gdata_documents_service.h
#ifndef CHROME_BROWSER_CHROMEOS_GDATA_MOCK_DOCUMENTS_SERVICE_H_
#define CHROME_BROWSER_CHROMEOS_GDATA_MOCK_DOCUMENTS_SERVICE_H_
#include <string>
#include "base/platform_file.h"
#include "base/memory/scoped_ptr.h"
-#include "chrome/browser/chromeos/gdata/documents_service_interface.h"
+#include "chrome/browser/chromeos/gdata/drive_service_interface.h"
#include "testing/gmock/include/gmock/gmock.h"
class FilePath;
namespace gdata {
-class MockDocumentsService : public DocumentsServiceInterface {
+class MockDriveService : public DriveServiceInterface {
public:
- // DocumentsService is usually owned and created by GDataFileSystem.
- MockDocumentsService();
- virtual ~MockDocumentsService();
+ // DriveService is usually owned and created by GDataFileSystem.
+ MockDriveService();
+ virtual ~MockDriveService();
- // DocumentServiceInterface overrides.
+ // DriveServiceInterface overrides.
MOCK_METHOD1(Initialize, void(Profile* profile));
MOCK_CONST_METHOD0(operation_registry, GDataOperationRegistry*());
MOCK_METHOD0(CancelAll, void(void));
@@ -192,4 +192,4 @@ class MockDocumentsService : public DocumentsServiceInterface {
} // namespace gdata
-#endif // CHROME_BROWSER_CHROMEOS_GDATA_MOCK_DOCUMENTS_SERVICE_H_
+#endif // CHROME_BROWSER_CHROMEOS_GDATA_MOCK_DRIVE_SERVICE_H_
« no previous file with comments | « chrome/browser/chromeos/gdata/mock_documents_service.cc ('k') | chrome/browser/chromeos/gdata/mock_drive_service.cc » ('j') | no next file with comments »

Powered by Google App Engine
@@ -2,29 +2,29 @@
// Use of this source code is governed by a BSD-style license that can be
// found in the LICENSE file.
-// This file contains mocks for classes in gdata_documents_service.h
+// This file contains mocks for classes in drive_service_interface.h
-#ifndef CHROME_BROWSER_CHROMEOS_GDATA_MOCK_DOCUMENTS_SERVICE_H_
-#define CHROME_BROWSER_CHROMEOS_GDATA_MOCK_DOCUMENTS_SERVICE_H_
+#ifndef CHROME_BROWSER_CHROMEOS_GDATA_MOCK_DRIVE_SERVICE_H_
+#define CHROME_BROWSER_CHROMEOS_GDATA_MOCK_DRIVE_SERVICE_H_
#include <string>
#include "base/platform_file.h"
This is Rietveld 408576698